///File : ConfigManager.hpp
//------------------------------------------------------------------------------
/*
    Copyright (C) 2009 Colin GILLE / congelli501

    This file is part of Devis Maker.
    Devis Maker is sold under Devis Maker license (read COPYING file)
*/
//------------------------------------------------------------------------------
#if not defined CONFIG_MANAGER_HPP
#define CONFIG_MANAGER_HPP
//------------------------------------------------------------------------------
#include <string>
#include <iostream>
#include <vector>
#include <map>
//------------------------------------------------------------------------------
#include "ItemSectionDBBase.hpp"
//------------------------------------------------------------------------------
#include "config.hpp"
#include "buildVersionOptions.hpp"
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
//------------------------------- ConfigManager --------------------------------
//------------------------------------------------------------------------------

struct StructStdColor
{
    unsigned char r, g, b;
};

struct StructStdFont
{
    int pointSize;
    std::string faceName;
    bool bold;
    bool italic;
    bool underligned;
};

struct StructStdColorFont
{
    StructStdFont font;
    StructStdColor color;
};

class ConfigManager
{
public:
    // Init
    ConfigManager();
    void LoadFromElement(ticpp::Element *root);
    //void LoadFromFile(std::string filename = "");
    void ClearAll();

    // Autre
    void operator=(const ConfigManager &src); // Copie des données uniquement

    // Sauvegarde
    ticpp::Element SaveToElement();
    //void SaveToFile(std::string filename = "");

    // Get
    bool GetBool(const std::string &key) const;
    int GetInt(const std::string &key) const;
    double GetDouble(const std::string &key) const;
    std::string GetString(const std::string &key) const;

    // Special
    StructStdFont GetFont(const std::string &key) const;
    StructStdColor GetColor(const std::string &key) const;
    StructStdColorFont GetColorFont(const std::string &key) const;

    // Set
    void SetBool(const std::string &key, const bool &value);
    void SetInt(const std::string &key, const int &value);
    void SetDouble(const std::string &key, const double &value);
    void SetString(const std::string &key, const std::string &value);

    // Special
    void SetFont(const std::string &key, const StructStdFont &value);
    void SetColor(const std::string &key, const StructStdColor &value);
    void SetColorFont(const std::string &key, const StructStdColorFont &value);

    // Test
    bool ExistsBool(const std::string &key) const;
    bool ExistsInt(const std::string &key) const;
    bool ExistsDouble(const std::string &key) const;
    bool ExistsString(const std::string &key) const;

    bool ExistsInCfg(const std::string &key) const;

    // Remove
    void RemoveBool(const std::string &key);
    void RemoveInt(const std::string &key);
    void RemoveDouble(const std::string &key);
    void RemoveString(const std::string &key);

    // Special
    void RemoveFont(const std::string &key);
    void RemoveColor(const std::string &key);
    void RemoveColorFont(const std::string &key);

    // Flags
    bool IsOk() const;
    bool IsModified() const;

    void SetModified(const bool &isModified);

    // Filename
    /*std::string GetFilename() const;
    void SetFilename(const std::string &filename);*/

protected:
    void ThrowNotOkIfNeeded() const;

    // Filename
    //std::string m_filename;

    // Flags
    bool m_isOk;
    bool m_isModified;

    // Data
    std::map<std::string, bool> m_DBbool;
    std::map<std::string, int> m_DBint;
    std::map<std::string, double> m_DBdouble;
    std::map<std::string, std::string> m_DBstring;
};

//------------------------------------------------------------------------------
//------------------------------- class GeneralCfg -----------------------------
//------------------------------------------------------------------------------

class GeneralCfg
{
public:
    GeneralCfg();
    void SaveToFile(const std::string &filename = "");
    void LoadFromFile(const std::string &filename = "");
    std::string GetFilename() const;
    void SetFilename(const std::string &filename);
    bool IsModified() const;
    ConfigManager& GetGeneralCfg();
    ConfigManager& GetDefaultDevisCfg();

    // Gestion de plusieurs cfg
    #if defined USE_MULTIPLE_CONFIG
    std::vector<std::string> GetCfgTbl() const;
    void SetDefaultCfgPos(const int &pos);
    int GetDefaultCfgPos() const;
    int GetCurrentCfgPos() const;
    int GetCfgCount() const;

    void SelectCfg(const int &pos);
    void RemoveCfg(const int &pos);
    void CopyCfg(const int &pos);
    #endif

protected:
    std::string m_filename;
    bool m_isModified;

    struct StructCfg
    {
        ConfigManager generalCfg;
        ConfigManager defaultDevisCfg;
    };

    #if defined USE_MULTIPLE_CONFIG
    std::vector<StructCfg> m_cfgTbl;
    int m_currentCfgPos;
    int m_defaultCfgPos;
    #else
    StructCfg m_cfg;
    #endif
};

#endif //CONFIG_MANAGER_HPP
