///File : DialogInfoGeneral.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "DialogInfoGeneral.hpp"
//------------------------------------------------------------------------------
DialogInfoGeneral::DialogInfoGeneral( wxWindow* parent, wxWindowID id, GeneralCfg *generalCfg, const wxString& title, const wxPoint& pos, const wxSize& size, long style ) : DialogProperty( parent, id, &(generalCfg->GetGeneralCfg()), NULL, title, pos, size, style )
{
    m_generalCfg = generalCfg;

    wxPanel *PagePanel;
    wxBoxSizer *PageSizer;
    //------------------------------------------------------------------------------
    // Base
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);

    AddParamCtrl(type_singleLine, PagePanel, PageSizer, "cfgName", _("Name :"));
    PageSizer->Add(new wxStaticLine(PagePanel, wxID_ANY), 0, wxEXPAND | wxALL, 5);
    // Modification devis par defaut
    PageSizer->Add(new wxStaticText(PagePanel, wxID_ANY, _("Edit the default properties :")), 0, wxALL, 5);
	wxButton *BtEditDefaultDevis = new wxButton(PagePanel, wxID_ANY, _("Edit default Invoice / Estimate"));
	PageSizer->Add(BtEditDefaultDevis, 0, wxALL, 5 );
	BtEditDefaultDevis->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(DialogInfoGeneral::OnEditDefaultDevis), NULL, this);
    // Reprise...
    PageSizer->Add(new wxStaticLine(PagePanel, wxID_ANY), 0, wxEXPAND | wxALL, 5);
    // Modification post info & pre info
    PageSizer->Add(new wxStaticText(PagePanel, wxID_ANY, _("Edit the begin and end presentation :")), 0, wxALL, 5);

    wxBoxSizer *tempSizer = new wxBoxSizer( wxVERTICAL ); // Pour que les deux boutons soient de la même taille.
    wxButton *bt;

	bt = new wxButton(PagePanel, wxID_ANY, _("Edit the begining presentation"));
	tempSizer->Add(bt, 0, wxEXPAND | wxALL, 5 );
	bt->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(DialogInfoGeneral::OnEditPreInfo), NULL, this);

	bt = new wxButton(PagePanel, wxID_ANY, _("Edit the end presentation"));
	tempSizer->Add(bt, 0, wxEXPAND | wxALL, 5 );
	bt->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(DialogInfoGeneral::OnEditPostInfo), NULL, this);

	PageSizer->Add(tempSizer, 0 );
    // Reprise...


    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Basic"));
    //------------------------------------------------------------------------------
    // Printing (Load, Save)
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);
    AddParamCtrl(type_check_enable_next, PagePanel, PageSizer, "startWithASection", _("Add an empty section in new Invoice / Estimate"));
    AddParamCtrl(type_singleLine, PagePanel, PageSizer, "startSectionName", _("Section's name :"));

    PageSizer->AddSpacer(15);

    AddParamCtrl(type_dir, PagePanel, PageSizer, "defaultSaveDir", _("Default directory :"));

    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Load, Save"));
    //------------------------------------------------------------------------------
    // Printing (Marging)
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);
    AddParamCtrl(type_check, PagePanel, PageSizer, "usePrinterMarging", _("Add to printer's marging (Windows only)"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "pageMargingLeft", _("Left :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "pageMargingTop", _("Top :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "pageMargingRight", _("Right :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "pageMargingBottom", _("Bottom :"));

    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Printing (Marging)"));
    //------------------------------------------------------------------------------
    // Printing (General)
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);
    AddParamCtrl(type_check_enable_next, PagePanel, PageSizer, "showTVAidInItemsTbl", _("Show taxe identifiant in items lines"));
    AddParamCtrl(type_check, PagePanel, PageSizer, "showTVAidInItemsTbl_OnlyIfMoreThanTVAid", _("...only if there is more than one taxe rate"));
    AddParamCtrl(type_check, PagePanel, PageSizer, "isPrintSections", _("Print section's names"));
    AddParamCtrl(type_check, PagePanel, PageSizer, "isTableMaxHeight", _("Maximum table height"));

    PageSizer->Add(new wxStaticLine(PagePanel, wxID_ANY), 0, wxEXPAND | wxALL, 5);

    AddParamCtrl(type_color, PagePanel, PageSizer, "tableColor", _("Tables color :"));
    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Printing (General)"));
    //------------------------------------------------------------------------------
    // Mesures / Printing (Advanced)
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);
    AddParamCtrl(type_int, PagePanel, PageSizer, "titleLineHeight", _("Title line height :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "tableVlineMarging", _("Marging around vertical lines :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "tableHlineMarging", _("Marging around horizontal lines :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "interSectionSpace", _("Inter sections gap :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "interItemsSpace", _("Inter lines gap in items table :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "interLineTVARecapTblSpace", _("Inter lines gap in taxe and total table :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "arcSize", _("Arc size :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "TVArecapTblInterSpace", _("Gap between taxe and total table :"));
    AddParamCtrl(type_int, PagePanel, PageSizer, "TVArecapTbANDitemsInterSapce", _("Gap between items table and taxe and total table :"));
    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Printing (Advanced)"));
    //------------------------------------------------------------------------------
    // Printing (Prices)
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);
    AddParamCtrl(type_int, PagePanel, PageSizer, "nb_synifNb", _("Significant figures :"));
    AddParamCtrl(type_check, PagePanel, PageSizer, "nb_rondIfTooMuchSynifNb", _("Round numbers if there is too much significant figures"));

    AddParamCtrl(type_check, PagePanel, PageSizer, "nb_addZeros", _("Add zeros if there is not enough much significant figures"));

    AddParamCtrl(type_singleLine, PagePanel, PageSizer, "nb_virguleString", _("Decimal point (\".\", \",\"...) :"));

    AddParamCtrl(type_check_enable_next, PagePanel, PageSizer, "nb_addSpaces", _("Add characters to make groupe of 3 numbers (ex: 12 598)"));
    AddParamCtrl(type_singleLine, PagePanel, PageSizer, "nb_spaceString", _("Space characters :"));

    AddParamCtrl(type_singleLine, PagePanel, PageSizer, "nb_before", _("Characters to add before the number :"));
    AddParamCtrl(type_singleLine, PagePanel, PageSizer, "nb_after", _("Characters to add after the number :"));

    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Printing (Prices)"));
    //------------------------------------------------------------------------------
    // Printing (Fonts)
    PagePanel = new MyGearsPanel(GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);

    AddParamCtrl(type_color_font, PagePanel, PageSizer, "tableItem", _("Items font :"));
    AddParamCtrl(type_color_font, PagePanel, PageSizer, "tableSectionTitle", _("Section titles font :"));
    AddParamCtrl(type_color_font, PagePanel, PageSizer, "tableTitle", _("Table title font :"));

    PagePanel->SetSizer(PageSizer);
    GetNotebook()->AddPage(PagePanel, _("Printing (Fonts)"));
}
//------------------------------------------------------------------------------

void DialogInfoGeneral::OnEditDefaultDevis(wxCommandEvent& event)
{
    try
    {
        DialogInfoDevis MyDialogInfoDevis(this, wxID_ANY, &m_generalCfg->GetDefaultDevisCfg(), NULL);
        if(MyDialogInfoDevis.ShowModal() == wxID_OK)
        {
            MyDialogInfoDevis.SaveCfg();
            if( m_generalCfg->GetDefaultDevisCfg().IsModified() )
            {
                m_isSubDialogModified = true;
                RefreshLabels();
            }
        }
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        wxMessageBox(_("Error : ") + wxString(_T("\n")) + StrStdToWx(e.what()), _("Error..."),  wxOK | wxICON_ERROR, this);
    }
}

//------------------------------------------------------------------------------
void DialogInfoGeneral::OnEditPreInfo(wxCommandEvent& event)
{
    DialogEditPrePostInfo("preInfo");
}
//------------------------------------------------------------------------------
void DialogInfoGeneral::OnEditPostInfo(wxCommandEvent& event)
{
    DialogEditPrePostInfo("postInfo");
}
//------------------------------------------------------------------------------
void DialogInfoGeneral::DialogEditPrePostInfo(const std::string &mainMdoSizerName)
{
    //Enable(false);

    try
    {
        ConfigManager tempCfgManager = *m_cfg;
        tempCfgManager.SetModified(false);

        DialogMdoEdit MyDialogMdoEdit(this, wxID_ANY, &tempCfgManager, mainMdoSizerName);
        MyDialogMdoEdit.ShowModal();
        /*if(MyDialogMdoEdit.ShowModal() == wxID_OK)
        {*/
            if( tempCfgManager.IsModified() )
            {
                m_isSubDialogModified = true;
                RefreshLabels();
                *m_cfg = tempCfgManager;
            }
        //}
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        wxMessageBox(_("Error : ") + wxString(_T("\n")) + StrStdToWx(e.what()), _("Error..."),  wxOK | wxICON_ERROR, this);
    }
}
//------------------------------------------------------------------------------
