///File : DialogMultiCfgManager.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "DialogMultiCfgManager.hpp"


#if defined USE_MULTIPLE_CONFIG
//------------------------------------------------------------------------------
//-                               DialogMultiCfgManager                                   -
//------------------------------------------------------------------------------
DialogMultiCfgManager::DialogMultiCfgManager( wxWindow* parent, wxWindowID id, GeneralCfg *generalCfg, const wxString &title, const wxPoint& pos, const wxSize& size, long style ) : wxDialog( parent, id, title, pos, size, style )
{
    // Devis Manager
    m_generalCfg = generalCfg;

	// Controls
        // Ref
	wxBoxSizer *MainSizer = new wxBoxSizer( wxVERTICAL );

	wxBoxSizer *ListBtSizer = new wxBoxSizer( wxHORIZONTAL );

        // List
    m_list = new wxListBox(this, wxID_ANY);
    ListBtSizer->Add(m_list, 1, wxEXPAND | wxALL, 5);

        // Bt (edit)
    wxBoxSizer *btSizer = new wxBoxSizer( wxVERTICAL );

    m_btCopy = new wxButton(this, wxID_COPY);
    btSizer->Add(m_btCopy, 0, wxEXPAND | wxALL, 5);

    m_btEdit = new wxButton(this, wxID_EDIT);
    btSizer->Add(m_btEdit, 0, wxEXPAND | wxALL, 5);

    m_btRemove = new wxButton(this, wxID_REMOVE);
    btSizer->Add(m_btRemove, 0, wxEXPAND | wxALL, 5);

    m_btSetDefault = new wxButton(this, wxID_ANY, _("&Default"));
    btSizer->Add(m_btSetDefault, 0, wxEXPAND | wxALL, 5);

    m_btSelect = new wxButton(this, wxID_ANY, _("&Select"));
    btSizer->Add(m_btSelect, 0, wxEXPAND | wxALL, 5);

	ListBtSizer->Add(btSizer, 0, wxEXPAND);

	MainSizer->Add(ListBtSizer, 1, wxEXPAND);


        // Bt (dialog)
    //MainSizer->Add(CreateButtonSizer(wxOK), 0, wxALL | wxALIGN_RIGHT, 5);

	SetSizer(MainSizer);

	// Events
    m_btCopy->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxEventHandler(DialogMultiCfgManager::OnCopy ), NULL, this);
    m_btRemove->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxEventHandler(DialogMultiCfgManager::OnRemove ), NULL, this);
    m_btSetDefault->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxEventHandler(DialogMultiCfgManager::OnSetDefault ), NULL, this);
    m_btEdit->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxEventHandler(DialogMultiCfgManager::OnEdit ), NULL, this);
    m_btSelect->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxEventHandler(DialogMultiCfgManager::OnSelectCfg ), NULL, this);

    m_list->Connect( wxEVT_KEY_DOWN, wxKeyEventHandler(DialogMultiCfgManager::OnListKeyDown ), NULL, this);

    // /!\ pas de 'm_SectionsList->Connect' ==> SegmentationFault quand on quitte avec wxGTK et wx2.8.9, après avoir utilisé l'event !!
    Connect(m_list->GetId(), wxEVT_COMMAND_LISTBOX_SELECTED, wxEventHandler(DialogMultiCfgManager::OnListSelect));

    m_list->Connect( wxEVT_LEFT_DCLICK, wxEventHandler(DialogMultiCfgManager::OnEdit), NULL, this);

    // Table
    FeedTbl();
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::RefreshBt()
{
    bool isSelected = m_list->GetSelection() != wxNOT_FOUND;

    m_btRemove->Enable(isSelected && m_list->GetCount() > 1 && m_generalCfg->GetCurrentCfgPos() != m_list->GetSelection() );
    m_btCopy->Enable(isSelected);
    m_btSetDefault->Enable(isSelected && m_generalCfg->GetDefaultCfgPos() != m_list->GetSelection());
    m_btEdit->Enable(isSelected);
    m_btSelect->Enable(isSelected && m_generalCfg->GetCurrentCfgPos() != m_list->GetSelection() );
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnListSelect(wxEvent& event)
{
    RefreshBt();
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnCopy(wxEvent& event)
{
    if(m_list->GetSelection() != wxNOT_FOUND)
    {
        m_generalCfg->CopyCfg(m_list->GetSelection());
        FeedTbl();
    }
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnSelectCfg(wxEvent& event)
{
    if(m_list->GetSelection() != wxNOT_FOUND)
    {
        m_generalCfg->SelectCfg(m_list->GetSelection());
        FeedTbl();
    }
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnRemove(wxEvent& event)
{
    if(m_list->GetSelection() != wxNOT_FOUND && m_list->GetCount() > 1 && m_generalCfg->GetCurrentCfgPos() != m_list->GetSelection())
    {
        if(wxMessageBox(_("This configuration will be removed.\nDo you want to continue ?"), _("Remove configuration"), wxYES_NO | wxYES_DEFAULT | wxICON_QUESTION, this) == wxYES)
        {
            m_generalCfg->RemoveCfg(m_list->GetSelection());
            FeedTbl();
        }
    }
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnEdit(wxEvent& event)
{
    int editPos = m_list->GetSelection();
    int backPos = m_generalCfg->GetCurrentCfgPos();
    if(editPos == wxNOT_FOUND)
    {
        return;
    }

    m_generalCfg->SelectCfg(editPos);
    bool isDefaultCfg = m_generalCfg->GetDefaultCfgPos() == editPos;

    try
    {
        DialogInfoGeneral MyDialogInfoGeneral(this, wxID_ANY, m_generalCfg);
        if(MyDialogInfoGeneral.ShowModal() == wxID_OK)
        {
            MyDialogInfoGeneral.SaveCfg();

            if(m_generalCfg->IsModified())
            {
                // Si par default ==> il faut le garder en cas de changement de nom...
                if(isDefaultCfg)
                {
                    m_generalCfg->SetDefaultCfgPos(editPos);
                }
            }

            m_generalCfg->SelectCfg(backPos);
            FeedTbl();
        }

        m_generalCfg->SelectCfg(backPos);
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        wxMessageBox(_("Error : ") + wxString(_T("\n")) + StrStdToWx(e.what()), _("Error..."),  wxOK | wxICON_ERROR, this);
    }
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnSetDefault(wxEvent& event)
{
    if(m_list->GetSelection() != wxNOT_FOUND)
    {
        m_generalCfg->SetDefaultCfgPos(m_list->GetSelection());
        FeedTbl();
    }
}
//------------------------------------------------------------------------------

void DialogMultiCfgManager::FeedTbl()
{
    wxWindowUpdateLocker winLock(m_list); // Bloque les redraw durant son temps de vie.

    //On met la liste à la bonne taille :
    int size = m_generalCfg->GetCfgCount();

    while(m_list->GetCount() > size)
    {
        m_list->Delete(m_list->GetCount() - 1);
    }
    while(m_list->GetCount() < size)
    {
        m_list->Append(_T(""));
    }

    // On change les labels...
    std::vector<std::string> stdList = m_generalCfg->GetCfgTbl();
    int defaultCfgPos = m_generalCfg->GetDefaultCfgPos();
    int currentCfgPos = m_generalCfg->GetCurrentCfgPos();

    for(int i = 0; i < stdList.size(); i++)
    {
        wxString tmp = StrStdToWx(stdList[i]);
        if(defaultCfgPos == i)
        {
            tmp += wxString(_T(" - ")) + wxString(_("Default"));
        }
        if(currentCfgPos == i)
        {
            tmp += wxString(_T(" - ")) + wxString(_("Current"));
        }

        if(m_list->GetString(i) != tmp) // ...Si il le faut
        {
            m_list->SetString(i, tmp);
        }
    }

    RefreshBt();
}
//------------------------------------------------------------------------------
void DialogMultiCfgManager::OnListKeyDown(wxKeyEvent& event)
{
    if(event.GetKeyCode() == WXK_DELETE)
    {
        wxCommandEvent tmp;
        OnRemove(tmp);
    }

    event.Skip();
}
//------------------------------------------------------------------------------

#endif // #if defined USE_MULTIPLE_CONFIG
