///File : StaticText.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "StaticText.hpp"
//------------------------------------------------------------------------------

namespace mdo
{

//------------------------------------------------------------------------------
//---------------------------------- Text --------------------------------------
//------------------------------------------------------------------------------
bool StaticText::CalculSizeReal(wxDC *dc, const int &width, const int &askedHeight)
{
    m_data.textToDraw = m_text;
    TextBase::CalculSizeReal(dc, width, askedHeight);
}
//------------------------------------------------------------------------------
StaticText::StaticText(ConfigManager *cfg, ConfigManager *devisCfg, DrawableObject *parrentSizer, const std::string &name) : TextBase(cfg, devisCfg, parrentSizer, name)
{
    m_typeName = MDO_STATIC_TEXT_TYPE_NAME;
    SetConfigName(""); // Rechargement du prefix
}
//------------------------------------------------------------------------------
void StaticText::LoadFromCfg(const std::string &name)
{
    TextBase::LoadFromCfg(name);
    m_text = StrStdToWx(m_cfg->GetString(m_cfgPrefix + "text"));
}
//------------------------------------------------------------------------------
void StaticText::SaveToCfg(const std::string &name)
{
    TextBase::SaveToCfg(name);
    m_cfg->SetString(m_cfgPrefix + "text", StrWxToStd(m_text));
}
//------------------------------------------------------------------------------
void StaticText::CreateToCfg(const std::string &name)
{
    TextBase::CreateToCfg(name);
    m_cfg->SetString(m_cfgPrefix + "text", StrWxToStd(_("Some text")));

    LoadFromCfg();
}
//------------------------------------------------------------------------------
void StaticText::RemoveFromCfg(const std::string &name, const bool &withChilds)
{
    TextBase::RemoveFromCfg(name);
    m_cfg->RemoveString(m_cfgPrefix + "text");
}
//------------------------------------------------------------------------------
void StaticText::EditPropertyDialog(DialogProperty *window)
{
    TextBase::EditPropertyDialog(window);

    wxPanel *PagePanel;
    wxBoxSizer *PageSizer;

    // Special Mdo
    PagePanel = new wxPanel(window->GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);

    window->AddParamCtrl(type_multiLine, PagePanel, PageSizer, m_cfgPrefix + "text", _("Text :"));

    PagePanel->SetSizer(PageSizer);
    window->GetNotebook()->AddPage(PagePanel, _("Text"));
}
//------------------------------------------------------------------------------


} // namespace mdo
